import {
  select,
  json,
  zoom,
  event,
  scaleOrdinal,
  schemeBlues
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { choroplethMap } from './choroplethMap';

const svg = select('svg');
const choroplethMapG = svg.append('g');
const colorLegendG = svg.append('g')
  .attr('transform', `translate(30, 300)`);

const colorScale = scaleOrdinal();

const colorValue = d => d.properties.economy;

let selectedColorValue;
let features;

const onClick = d => {
  selectedColorValue = d;
  render();
};

loadAndProcessData().then(countries => {
  console.log(countries);
  features = countries.features;
  render();
});

const render = () => {
	colorScale
    .domain(features.map(colorValue))
    .domain(colorScale.domain().sort().reverse())
  	.range(['developed-g7', 'developed', 'bric', 'mikt', 'emerging-g20', 'developing', 'least-developed'].reverse());
  
  colorLegendG
    .call(colorLegend, {
      colorScale,
      circleRadius: 8,
      spacing: 20,
      textOffset: 15,
    	backgroundRectWidth: 240,
    	onClick,
    	selectedColorValue
  });
  
  choroplethMapG.call(choroplethMap, {
  	features,
    colorScale,
    colorValue,
    selectedColorValue
  });
  
}; 